<template>
  <div>
    <el-form ref="loginForm"
             :model="loginForm"
             :rules="loginRules"
             class="login-form"
             label-width="0"
             status-icon
    >
      <el-form-item prop="selectInput">
        <el-select v-model="loginForm.tenantId" placeholder="请选择租户" style="width: 100%" @change="selectChange">
          <i slot="prefix" class="el-icon-s-operation"/>
          <el-option
            v-for="(item,index) in loginForm.region"
            :key="index"
            :label="item.TENANT_NAME"
            :value="item.TENANT_ID">
          </el-option>
        </el-select>
      </el-form-item>
      <el-form-item prop="username">
        <el-input v-model="loginForm.username"
                  :placeholder="$t('login.username')"
                  auto-complete="off"
                  size="small"
                  @keyup.enter.native="handleLogin">
          <i slot="prefix" class="icon-yonghu"/>
        </el-input>
      </el-form-item>
      <el-form-item prop="password">
        <el-input v-model="loginForm.password"
                  :placeholder="$t('login.password')"
                  :type="passwordType"
                  auto-complete="off"
                  size="small"
                  @keyup.enter.native="handleLogin">
          <i slot="suffix" class="el-icon-view el-input__icon" @click="showPassword"/>
          <i slot="prefix" class="icon-mima"/>
        </el-input>
      </el-form-item>

      <el-form-item>
        <el-button @click="ChandleLogin">测试单点登录</el-button>
        <el-button class="login-submit"
                   size="small"
                   type="primary"
                   @click.native.prevent="handleLogin">{{ $t('login.submit') }}
        </el-button>
      </el-form-item>
      <!--密码修改弹出框-->
    </el-form>
    <el-dialog :close-on-press-escape="false" :visible.sync="dialogFormVisible" append-to-body title="修改密码"
               @closed="closehandle">
      <el-form :model="form" :rules="rules">
        <el-form-item :label-width="formLabelWidth" label="原密码" prop="oldPassword">
          <el-input v-model="form.oldPassword" autocomplete="off"></el-input>
        </el-form-item>
        <el-form-item :label-width="formLabelWidth" label="新密码" prop="newPassword">
          <el-input v-model="form.newPassword" autocomplete="off"></el-input>
        </el-form-item>
        <el-form-item :label-width="formLabelWidth" label="确认密码" prop="newPassword1">
          <el-input v-model="form.newPassword1" autocomplete="off"></el-input>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button @click="delok">取 消</el-button>
        <el-button type="primary" @click="addHandler">确 定</el-button>
      </div>
    </el-dialog>
  </div>

</template>

<script>
import {mapGetters} from "vuex";
import {info} from "@/api/system/tenant";
import {getTopUrl} from "@/util/util";
import { updatePassword} from "@/api/system/user.js"
import {removeToken} from "@/util/auth";
import md5 from "js-md5";

export default {
  name: "userlogin",
  data() {
    return {
      tenantMode: this.website.tenantMode,
      ButtonList: [],
      dialogFormVisible: false,
      form: {
        oldPassword: '',
        newPassword: '',
        newPassword1: '',
      },
      loginRules: {
        username: [
          {required: true, message: '请输入账号', trigger: 'blur'}
        ],
        password: [
          {required: true, message: '请输入密码', trigger: 'blur'}
        ],
      },
      rules: {
        oldPassword: [
          {required: true, message: '请输入原密码', trigger: 'blur'}
        ],
        newPassword: [
          {required: true, message: '请输入新密码', trigger: 'blur'}
        ],
        newPassword1: [
          {required: true, message: '请输确认密码', trigger: 'blur'}
        ]
      },
      loginForm: {
        //租户ID
        tenantId: "",
        //部门ID
        deptId: "",
        //角色ID
        roleId: "",
        //用户名
        username: "",
        //密码
        password: "",
        selectInput: '',
        //下拉input数据
        value: '管理组',
        //下拉菜单
        region: [],
        //账号类型
        type: "account",
        //验证码的索引
        key: "",
        //预加载白色背景
        image: "data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7",

      },
      value: {
        selectInput: [
          {required: true, message: "请选择租户", trigger: "blur"}
        ],
        username: [
          {required: true, message: "请输入用户名", trigger: "blur"}
        ],
        password: [
          {required: true, message: "请输入密码", trigger: "blur"},
          {min: 1, message: "密码长度最少为6位", trigger: "blur"}
        ]
      },
      passwordType: "password",
      userBox: false,
      userForm: {
        deptId: '',
        roleId: ''
      },
      userinfo: []
    };
  },
  created() {
    this.getTenant();
    //这里是浏览器的一个bug，突然出现的目前找不到原因，新的浏览器打开此项目。localStorage会少存储一个名为saber-permission的数据，少了这条数据租户管理界面会缺少几个按钮和样式
    localStorage.setItem("saber-permission", JSON.stringify({
      "dataType": "object", "content": {
        "flow_model_create": true,
        "flow_model_update": true,
        "flow_model_deploy": true,
        "flow_model_download": true,
        "flow_model_delete": true,
        "work_start_flow": true,
        "work_start_image": true,
        "oss_add": true,
        "oss_edit": true,
        "oss_delete": true,
        "oss_view": true,
        "oss_enable": true,
        "role_add": true,
        "role_edit": true,
        "role_delete": true,
        "role_view": true,
        "notice_add": true,
        "notice_edit": true,
        "notice_delete": true,
        "notice_view": true,
        "user_add": true,
        "user_edit": true,
        "user_delete": true,
        "user_role": true,
        "user_reset": true,
        "user_view": true,
        "log_usual_view": true,
        "code_add": true,
        "code_edit": true,
        "code_delete": true,
        "code_view": true,
        "region_add": true,
        "region_delete": true,
        "region_import": true,
        "region_export": true,
        "region_debug": true,
        "work_claim_sign": true,
        "work_claim_detail": true,
        "work_claim_follow": true,
        "work_todo_handle": true,
        "work_todo_detail": true,
        "work_todo_follow": true,
        "data_scope_setting": true,
        "datasource_add": true,
        "datasource_edit": true,
        "datasource_delete": true,
        "datasource_view": true,
        "attach_upload": true,
        "attach_download": true,
        "attach_delete": true,
        "dept_add": true,
        "dept_edit": true,
        "dept_delete": true,
        "dept_view": true,
        "log_api_view": true,
        "flow_manager_state": true,
        "flow_manager_image": true,
        "flow_manager_remove": true,
        "work_send_detail": true,
        "work_send_follow": true,
        "sms_add": true,
        "sms_edit": true,
        "sms_delete": true,
        "sms_view": true,
        "sms_enable": true,
        "api_scope_setting": true,
        "log_error_view": true,
        "post_add": true,
        "post_edit": true,
        "post_delete": true,
        "post_view": true,
        "flow_follow_delete": true,
        "work_done_detail": true,
        "work_done_follow": true,
        "dict_add": true,
        "dict_edit": true,
        "dict_delete": true,
        "dict_view": true,
        "dictbiz_add": true,
        "dictbiz_edit": true,
        "dictbiz_delete": true,
        "dictbiz_view": true,
        "menu_add": true,
        "menu_edit": true,
        "menu_delete": true,
        "menu_view": true,
        "topmenu_add": true,
        "topmenu_edit": true,
        "topmenu_delete": true,
        "topmenu_view": true,
        "topmenu_setting": true,
        "param_add": true,
        "param_edit": true,
        "param_delete": true,
        "param_view": true,
        "tenant_add": true,
        "tenant_edit": true,
        "tenant_delete": true,
        "tenant_view": true,
        "client_add": true,
        "client_edit": true,
        "client_delete": true,
        "client_view": true
      }, "datetime": 1678352291697
    }))
  },
  mounted() {
    this.$axios.get('/api/ubcs-system/tenant/tenant-map').then(res => {
      if (res.data.code == 200) {
        this.loginForm.tenantId = res.data.data[0].TENANT_ID;
        this.loginForm.region = res.data.data
      }
    })
  },
  watch: {
    'loginForm.deptId'() {
      const column = this.findObject(this.userOption.column, "deptId");
      if (this.loginForm.deptId.includes(",")) {
        column.dicUrl = `/api/ubcs-system/dept/select?deptId=${this.loginForm.deptId}`;
        column.display = true;
      } else {
        column.dicUrl = '';
      }
    },
    'loginForm.roleId'() {
      const column = this.findObject(this.userOption.column, "roleId");
      if (this.loginForm.roleId.includes(",")) {
        column.dicUrl = `/api/ubcs-system/role/select?roleId=${this.loginForm.roleId}`;
        column.display = true;
      } else {
        column.dicUrl = '';
      }
    }
  },
  computed: {
    ...mapGetters(["tagWel", "userInfo"])
  },
  props: [],
  methods: {
    //单点登录跳转
    ChandleLogin() {
      this.$router.push({ path: '/sso' });
    },
    closehandle() {
      removeToken()
    },
    delok() {
      //点击取消或者x 清除token关闭弹窗 清除token后会自动重新获取用户信息
      this.dialogFormVisible = false;
      removeToken()
    },
    // 点击确定修改密码
    addHandler() {
      this.dialogFormVisible = false
      updatePassword(md5(this.form.oldPassword), this.form.newPassword, this.form.newPassword1).then(res => {
        console.log(res)
        if (res.data.code == 200) {
          this.$message({
            type: "success",
            message: "修改成功！"
          })
          this.$router.push({path: this.tagWel.value})
        }
      })
    },
    // 绑定下拉菜单动态ID
    selectChange(value) {
      this.loginForm.tenantId = value
    },
    showPassword() {
      this.passwordType === ""
        ? (this.passwordType = "password")
        : (this.passwordType = "");
    },
    submitLogin(form, done) {
      if (form.deptId !== '') {
        this.loginForm.deptId = form.deptId;
      }
      if (form.roleId !== '') {
        this.loginForm.roleId = form.roleId;
      }
      this.handleLogin();
      done();

    },
    handleLogin: function () {
      this.userInfo = this.$store.state.upadatastatus
      localStorage.setItem('username', this.loginForm.username)
      this.$refs.loginForm.validate(valid => {
        if (valid) {
          const loading = this.$loading({
            lock: true,
            text: '登录中,请稍后。。。',
            spinner: "el-icon-loading"
          });
          this.$store.dispatch("LoginByUsername", this.loginForm).then(() => {
            //上面又加了一层判断的意思是如果是超管不进行判断 暂时加上这个判断的话，登录会有bug，点击登录刷新后才进入，先简单在下面判断是否为空，只有超管的strategyUpdateStatus为空
            // if(this.userInfo.user_id != '0' && this.userInfo.tenant_id !== '000000'){
            //判断如果不等于0就是策略密码没有修改走下面逻辑
            if (this.userInfo.strategyUpdateStatus == 0 || this.userInfo.strategyUpdateStatus == null) {
              if (this.website.switchMode) {
                const deptId = this.userInfo.dept_id;
                const roleId = this.userInfo.role_id;
                if (deptId.includes(",") || roleId.includes(",")) {
                  this.loginForm.deptId = deptId;
                  this.loginForm.roleId = roleId;
                  this.userBox = true;
                  this.$store.dispatch("LogOut").then(() => {
                    loading.close();
                  });
                }
              }
              this.$router.push({path: this.tagWel.value});
            } else {
              //等于0说明密码策略被修改，提示用户修改密码，给一个修改弹框
              this.$message({
                type: "warning",
                message: "密码策略已被修改，请重新修改密码！"
              })
              setTimeout(() => {
                this.dialogFormVisible = true
              }, 1500)
            }

            // }
            //把判断密码策略修改的值存进本地，然后再路由权限js文件里面获取再做判断，不然刷新会进入首页（因为在有id和token的情况下，刷新页面或者进入登录页会自动进入首页）
            //index页面也可以用到这个值来判断是否是超管身份登录来判断是否提醒过期时间等
            localStorage.setItem("updataid", JSON.stringify(this.userInfo))
            localStorage.setItem("userId", this.userInfo.user_id)
            loading.close();
          }).catch(() => {
            loading.close();

          });
        }
      });
    },
    getTenant() {
      let domain = getTopUrl();
      // 临时指定域名，方便测试
      //domain = "https://bladex.vip";
      info(domain).then(res => {
        const data = res.data;
        if (data.success && data.data.tenantId) {
          this.tenantMode = false;
          this.loginForm.tenantId = data.data.tenantId;
          this.$parent.$refs.login.style.backgroundImage = `url(${data.data.backgroundUrl})`;
        }
      })
    }
  }
};
</script>

<style>
</style>
